==> babel-build-1.0.0.tgz: package/lib/copy.js <==
'use strict';

var copyFiles = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(source, target, watch) {
    var _this = this;

    var ncp, dir, watcher;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            ncp = _bluebird2.default.promisify(require('ncp'));
            dir = _path2.default.dirname(target);

            if (_fs2.default.existsSync(dir)) {
              _context2.next = 5;
              break;
            }

            _context2.next = 5;
            return (0, _utils.makeDir)(dir);

          case 5:
            _context2.next = 7;
            return ncp(source, target);

          case 7:
            if (!watch) {
              _context2.next = 12;
              break;
            }

            _context2.next = 10;
            return new _bluebird2.default(function (resolve, reject) {
              (0, _gaze2.default)(_path2.default.join(source, '**/*.*'), function (err, val) {
                return err ? reject(err) : resolve(val);
              });
            });

          case 10:
            watcher = _context2.sent;

            watcher.on('changed', function () {
              var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee(file) {
                var relPath;
                return regeneratorRuntime.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        relPath = file.substr(_path2.default.join(process.cwd(), source).length);

                        console.log(relPath + ' changed');
                        _context.next = 4;
                        return ncp('' + paht.join(source, relPath), '' + _path2.default.join(target, relPath));

                      case 4:
                      case 'end':
                        return _context.stop();
                    }
                  }
                }, _callee, _this);
              }));

              return function (_x4) {
                return _ref2.apply(this, arguments);
              };
            }());

          case 12:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function copyFiles(_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _gaze = require('gaze');

var _gaze2 = _interopRequireDefault(_gaze);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new _bluebird2.default(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return _bluebird2.default.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  */


module.exports = function () {
  var _ref3 = _asyncToGenerator(regeneratorRuntime.mark(function _callee3(task, watch) {
    var i, _task$i, source, target;

    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            if (!(task.constructor.name == 'Array')) {
              _context3.next = 12;
              break;
            }

            i = 0;

          case 2:
            if (!(i < task.length)) {
              _context3.next = 10;
              break;
            }

            _task$i = task[i], source = _task$i.source, target = _task$i.target;

            if (!(source && target)) {
              _context3.next = 7;
              break;
            }

            _context3.next = 7;
            return copyFiles(source, target, watch);

          case 7:
            i++;
            _context3.next = 2;
            break;

          case 10:
            _context3.next = 25;
            break;

          case 12:
            if (!(task.constructor.name == 'Object')) {
              _context3.next = 23;
              break;
            }

            source = task.source, target = task.target;

            if (!(source && target)) {
              _context3.next = 19;
              break;
            }

            _context3.next = 17;
            return copyFiles(source, target, watch);

          case 17:
            _context3.next = 21;
            break;

          case 19:
            _context3.next = 21;
            return console.log(_chalk2.default.bold.red('No copy task. Source and target should not be null.'));

          case 21:
            _context3.next = 25;
            break;

          case 23:
            _context3.next = 25;
            return console.log(_chalk2.default.bold.red('No copy task.'));

          case 25:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  function copy(_x5, _x6) {
    return _ref3.apply(this, arguments);
  }

  return copy;
}();

==> babel-build-1.0.2.tgz: package/lib/copy.js <==
'use strict';

var copyFiles = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(source, target, watch) {
    var _this = this;

    var ncp, dir, watcher;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            ncp = _bluebird2.default.promisify(require('ncp'));
            dir = _path2.default.dirname(target);

            if (_fs2.default.existsSync(dir)) {
              _context2.next = 5;
              break;
            }

            _context2.next = 5;
            return (0, _utils.makeDir)(dir);

          case 5:
            _context2.next = 7;
            return ncp(source, target);

          case 7:
            if (!watch) {
              _context2.next = 12;
              break;
            }

            _context2.next = 10;
            return new _bluebird2.default(function (resolve, reject) {
              (0, _gaze2.default)(_path2.default.join(source, '**/*.*'), function (err, val) {
                return err ? reject(err) : resolve(val);
              });
            });

          case 10:
            watcher = _context2.sent;

            watcher.on('changed', function () {
              var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee(file) {
                var relPath;
                return regeneratorRuntime.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        relPath = file.substr(_path2.default.join(process.cwd(), source).length);

                        console.log(relPath + ' changed');
                        _context.next = 4;
                        return ncp('' + _path2.default.join(source, relPath), '' + _path2.default.join(target, relPath));

                      case 4:
                      case 'end':
                        return _context.stop();
                    }
                  }
                }, _callee, _this);
              }));

              return function (_x4) {
                return _ref2.apply(this, arguments);
              };
            }());

          case 12:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function copyFiles(_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _gaze = require('gaze');

var _gaze2 = _interopRequireDefault(_gaze);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new _bluebird2.default(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return _bluebird2.default.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  */


module.exports = function () {
  var _ref3 = _asyncToGenerator(regeneratorRuntime.mark(function _callee3(task, watch) {
    var i, _task$i, source, target;

    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            if (!(task.constructor.name == 'Array')) {
              _context3.next = 12;
              break;
            }

            i = 0;

          case 2:
            if (!(i < task.length)) {
              _context3.next = 10;
              break;
            }

            _task$i = task[i], source = _task$i.source, target = _task$i.target;

            if (!(source && target)) {
              _context3.next = 7;
              break;
            }

            _context3.next = 7;
            return copyFiles(source, target, watch);

          case 7:
            i++;
            _context3.next = 2;
            break;

          case 10:
            _context3.next = 25;
            break;

          case 12:
            if (!(task.constructor.name == 'Object')) {
              _context3.next = 23;
              break;
            }

            source = task.source, target = task.target;

            if (!(source && target)) {
              _context3.next = 19;
              break;
            }

            _context3.next = 17;
            return copyFiles(source, target, watch);

          case 17:
            _context3.next = 21;
            break;

          case 19:
            _context3.next = 21;
            return console.log(_chalk2.default.bold.red('No copy task. Source and target should not be null.'));

          case 21:
            _context3.next = 25;
            break;

          case 23:
            _context3.next = 25;
            return console.log(_chalk2.default.bold.red('No copy task.'));

          case 25:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  function copy(_x5, _x6) {
    return _ref3.apply(this, arguments);
  }

  return copy;
}();
